==> TreeTools_1.6.0.tar.gz: TreeTools/tests/testthat/test-RoguePlot.R <==
AllTreesCounted <- function (trees, rogue) {
  x <- RoguePlot(trees, rogue, plot = FALSE)
  expect_equal(length(trees), sum(x$onEdge, x$atNode))
}

test_that('Simple rogue plot', {
  trees <- list(read.tree(text = '(a, (b, (c, (rogue, (d, e)))));'),
                read.tree(text = '(a, (b, (c, (rogue, (d, e)))));'),
                read.tree(text = '(a, (b, (c, (rogue, (d, e)))));'),
                read.tree(text = '(a, (b, (c, (d, (rogue, e)))));'))
  expect_equal(list(cons = Preorder(read.tree(text = '(a, (b, (c, (d, e))));')),
                    onEdge = c(0, 0, 0, 0, 0, 3, 0, 1),
                    atNode = double(4)),
               RoguePlot(trees, tip = 'rogue', plot = FALSE))

  skip_if_not_installed('vdiffr', '1.0')
  skip_if_not_installed('ape', '5.5.2')
  RoguePlotTest <- function () {
    par(mar = rep(0, 4))
    RoguePlot(trees, 'rogue',
              Palette = function(...) hcl.colors(..., palette = 'inferno'),
              thin = 2, fat = 4, edge.lty = 2)
  }
  vdiffr::expect_doppelganger('RoguePlot(simple)', RoguePlotTest)
})

test_that("polytomy id", {
  trees <- list(read.tree(text = "(a,(((b,(c,d)),e),rogue));"),
                read.tree(text = "(a,((((c,d),e),rogue),b));"),
                read.tree(text = "(a,(rogue,(e,((b,d),c))));"))
  AllTreesCounted(trees, 'rogue')

  expect_equal(list(cons = Preorder(read.tree(text = '(a, (b, c, d, e));')),
                    onEdge = c(0, 2, 0, 0, 0, 0),
                    atNode = c(0, 1)),
               RoguePlot(trees, 'rogue', plot = FALSE))

  skip_if_not_installed('vdiffr', '1.0')
  RoguePlotTest <- function () {
    par(mar = rep(0, 4))
    RoguePlot(trees, 'rogue')
  }
  vdiffr::expect_doppelganger('RoguePlot(poly)', RoguePlotTest)
})

# TODO test tree with rogue to left and right of balanced root
test_that('Complex rogue plot', {

  trees1 <- list(read.tree(text = '(a, (b, (c, (rogue, (d, (e, f))))));'),  # node 9
                 read.tree(text = '(a, (b, (c, (rogue, (d, (e, f))))));'),  # node 9
                 read.tree(text = '(a, (b, (c, (rogue, (d, (f, e))))));'),  # node 9
                 read.tree(text = '(a, (b, (c, (rogue, ((e, f), d)))));'),  # node 9
                 read.tree(text = '(a, (b, (c, (rogue, (d, (e, f))))));'),  # node 9 x 5
                 read.tree(text = '(rogue, (a, (b, (c, (d, (e, f))))));'),  # node 7 x 1
                 read.tree(text = '(a, (rogue, (b, (c, (d, (e, f))))));'),  # edge 2 x 1
                 read.tree(text = '((rogue, a), (b, (c, (d, (e, f)))));'),  # edge 1
                 read.tree(text = '((rogue, a), (b, (c, (d, (e, f)))));'),  # edge 1 x 2
                 read.tree(text = '(a, (b, ((c, d), (rogue, (f, e)))));'),  # edge 7
                 read.tree(text = '(a, (b, (((rogue, d), c), (e, f))));'),  # edge 6 x 1
                 read.tree(text = '(a, (b, (c, (d, (rogue, (e, f))))));'))  # edge 7 x 2
  expect_equal(list(cons = Preorder(read.tree(text = '(a, (b, (c, d, (e, f))));')),
                    onEdge = c(2, 1, 0, 0, 0, 1, 2, 0, 0),
                    atNode = c(1, 0, 5, 0)),
               RoguePlot(trees = trees1, tip = 'rogue', plot = FALSE))

  expect_equal(list(cons = Preorder(RenumberTips(
    read.tree(text = '(f, (e, (d, c, (b, a))));'), letters[1:6])),
                    onEdge = c(0, 2, 0, 4, 0, 0, 1, 0, 0),
                    atNode = c(0, 0, 5, 0)),
               RoguePlot(trees1, 'rogue', outgroupTips = 'f', plot = FALSE))

  trees2 <- list(read.tree(text = '(a, (b, (rogue, ((d, c), (e, f)))));'),
                 read.tree(text = '(a, (b, ((rogue, (d, c)), (e, f))));'),
                 read.tree(text = '(a, (b, ((rogue, (d, c)), (e, f))));'),
                 read.tree(text = '(a, ((b, (c, d)), (rogue, (e, f))));'),
                 read.tree(text = '(a, (b, ((c, d), (rogue, (e, f)))));'),
                 read.tree(text = '(a, (b, ((c, d), (rogue, (e, f)))));'))
  expected <- list(cons = Preorder(read.tree(text = '(a, (b, (c, d), (e, f)));')),
                   onEdge = c(0, 0, 0, 2, 0, 0, 3, 0, 0),
                   atNode = c(0, 1, 0, 0))
  actual <- RoguePlot(trees = trees2, tip = 'rogue', plot = FALSE)
  expect_equal(names(actual), names(expected))
  expect_true(all.equal(actual$cons, expected$cons))
  expect_equal(actual$onEdge, expected$onEdge)
  expect_equal(actual$atNode, expected$atNode)

  trees3 <- lapply(c(9, 10, 13), AddTip, tree = BalancedTree(8), label = 'rogue')
  AllTreesCounted(trees3, 'rogue')

  skip_if_not_installed('vdiffr', '1.0')
  skip_if_not_installed('ape', '5.5.2')
  RoguePlotTest <- function () {
    par(mar = rep(0, 4))
    RoguePlot(trees1, 'rogue',
              Palette = function(...) hcl.colors(..., palette = 'inferno'),
              edgeLen = 1, thin = 2, fat = 4)
  }
  vdiffr::expect_doppelganger('RoguePlot(trees1)', RoguePlotTest)

  RoguePlotTest <- function () {
    par(mar = rep(0, 4))
    RoguePlot(trees2, 'rogue', edgeLength = 1:7, thin = 2, fat = 4)
  }
  vdiffr::expect_doppelganger('RoguePlot(trees2)', RoguePlotTest)
})

==> TreeTools_1.7.0.tar.gz: TreeTools/tests/testthat/test-RoguePlot.R <==
AllTreesCounted <- function(trees, rogue) {
  x <- RoguePlot(trees, rogue, plot = FALSE)
  expect_equal(length(trees), sum(x$onEdge, x$atNode))
}

ExpectedCons <- function(text) {
  Preorder(read.tree(text = text))
}

test_that('Simple rogue plot', {
  trees <- list(read.tree(text = '(a, (b, (c, (rogue, (d, e)))));'),
                read.tree(text = '(a, (b, (c, (rogue, (d, e)))));'),
                read.tree(text = '(a, (b, (c, (rogue, (d, e)))));'),
                read.tree(text = '(a, (b, (c, (d, (rogue, e)))));'))
  expect_equal(
    RoguePlot(trees, tip = "rogue", plot = FALSE),
    list(cons = ExpectedCons("(a, (b, (c, (d, e))));"),
         onEdge = c(0, 0, 0, 0, 0, 3, 0, 1),
         atNode = double(4))
  )

  skip_if_not_installed("vdiffr", "1.0")
  skip_if_not_installed("ape", "5.5.2")
  RoguePlotTest <- function() {
    par(mar = rep(0, 4))
    RoguePlot(trees, 'rogue',
              Palette = function(...) hcl.colors(..., palette = 'inferno'),
              thin = 2, fat = 4, edge.lty = 2)
  }
  vdiffr::expect_doppelganger('RoguePlot(simple)', RoguePlotTest)
})

test_that("polytomy id", {
  trees <- list(read.tree(text = "(a,(((b,(c,d)),e),rogue));"),
                read.tree(text = "(a,((((c,d),e),rogue),b));"),
                read.tree(text = "(a,(rogue,(e,((b,d),c))));"))
  AllTreesCounted(trees, 'rogue')

  expect_equal(list(cons = ExpectedCons("(a, (b, c, d, e));"),
                    onEdge = c(0, 2, 0, 0, 0, 0),
                    atNode = c(0, 1)),
               RoguePlot(trees, "rogue", plot = FALSE))

  skip_if_not_installed('vdiffr', '1.0')
  RoguePlotTest <- function() {
    par(mar = rep(0, 4))
    RoguePlot(trees, 'rogue')
  }
  vdiffr::expect_doppelganger('RoguePlot(poly)', RoguePlotTest)
})

# TODO test tree with rogue to left and right of balanced root
test_that('Complex rogue plot', {

  trees1 <- list(read.tree(text = '(a, (b, (c, (rogue, (d, (e, f))))));'),  # node 9
                 read.tree(text = '(a, (b, (c, (rogue, (d, (e, f))))));'),  # node 9
                 read.tree(text = '(a, (b, (c, (rogue, (d, (f, e))))));'),  # node 9
                 read.tree(text = '(a, (b, (c, (rogue, ((e, f), d)))));'),  # node 9
                 read.tree(text = '(a, (b, (c, (rogue, (d, (e, f))))));'),  # node 9 x 5
                 read.tree(text = '(rogue, (a, (b, (c, (d, (e, f))))));'),  # node 7 x 1
                 read.tree(text = '(a, (rogue, (b, (c, (d, (e, f))))));'),  # edge 2 x 1
                 read.tree(text = '((rogue, a), (b, (c, (d, (e, f)))));'),  # edge 1
                 read.tree(text = '((rogue, a), (b, (c, (d, (e, f)))));'),  # edge 1 x 2
                 read.tree(text = '(a, (b, ((c, d), (rogue, (f, e)))));'),  # edge 7
                 read.tree(text = '(a, (b, (((rogue, d), c), (e, f))));'),  # edge 6 x 1
                 read.tree(text = '(a, (b, (c, (d, (rogue, (e, f))))));'))  # edge 7 x 2
  expect_equal(
    RoguePlot(trees = trees1, tip = 'rogue', plot = FALSE),
    list(cons = ExpectedCons("(a, (b, (c, d, (e, f))));"),
         onEdge = c(2, 1, 0, 0, 0, 1, 2, 0, 0),
         atNode = c(1, 0, 5, 0))
    )

  expectedCons <- Preorder(RenumberTips(
    read.tree(text = '(f, (e, (d, c, (b, a))));'), letters[1:6]))
  
  expect_equal(list(cons = expectedCons,
                    onEdge = c(0, 2, 0, 4, 0, 0, 1, 0, 0),
                    atNode = c(0, 0, 5, 0)),
               RoguePlot(trees1, 'rogue', outgroupTips = 'f', plot = FALSE))

  trees2 <- list(read.tree(text = '(a, (b, (rogue, ((d, c), (e, f)))));'),
                 read.tree(text = '(a, (b, ((rogue, (d, c)), (e, f))));'),
                 read.tree(text = '(a, (b, ((rogue, (d, c)), (e, f))));'),
                 read.tree(text = '(a, ((b, (c, d)), (rogue, (e, f))));'),
                 read.tree(text = '(a, (b, ((c, d), (rogue, (e, f)))));'),
                 read.tree(text = '(a, (b, ((c, d), (rogue, (e, f)))));'))
  expected <- list(cons = Preorder(read.tree(text = '(a, (b, (c, d), (e, f)));')),
                   onEdge = c(0, 0, 0, 2, 0, 0, 3, 0, 0),
                   atNode = c(0, 1, 0, 0))
  actual <- RoguePlot(trees = trees2, tip = 'rogue', plot = FALSE)
  expect_equal(names(actual), names(expected))
  expect_true(all.equal(actual$cons, expected$cons))
  expect_equal(actual$onEdge, expected$onEdge)
  expect_equal(actual$atNode, expected$atNode)

  trees3 <- lapply(c(9, 10, 13), AddTip, tree = BalancedTree(8), label = 'rogue')
  AllTreesCounted(trees3, 'rogue')

  skip_if_not_installed('vdiffr', '1.0')
  skip_if_not_installed('ape', '5.5.2')
  RoguePlotTest <- function() {
    par(mar = rep(0, 4))
    RoguePlot(trees1, 'rogue',
              Palette = function(...) hcl.colors(..., palette = 'inferno'),
              edgeLen = 1, thin = 2, fat = 4)
  }
  vdiffr::expect_doppelganger('RoguePlot(trees1)', RoguePlotTest)

  RoguePlotTest <- function() {
    par(mar = rep(0, 4))
    RoguePlot(trees2, 'rogue', edgeLength = 1:7, thin = 2, fat = 4)
  }
  vdiffr::expect_doppelganger('RoguePlot(trees2)', RoguePlotTest)
})
